clj-xref.analyze

Transform clj-kondo analysis data into the clj-xref data model.

Transform clj-kondo analysis data into the clj-xref data model.
raw docstring

analyzeclj

(analyze paths & [{:keys [project kondo-config]}])

Run clj-kondo analysis on paths and return a flat xref database map. Options: :project - project name string :kondo-config - extra config map merged into clj-kondo config

Run clj-kondo analysis on `paths` and return a flat xref database map.
Options:
  :project      - project name string
  :kondo-config - extra config map merged into clj-kondo config
sourceraw docstring

merge-analysisclj

(merge-analysis existing-db new-db files)

Merge new analysis into an existing database, replacing entries from the re-analyzed files. Used for incremental updates.

Merge new analysis into an existing database, replacing entries from
the re-analyzed files. Used for incremental updates.
sourceraw docstring

transform-analysisclj

(transform-analysis analysis {:keys [paths project]})

Transform raw clj-kondo analysis data into the clj-xref data model. Returns a flat (unindexed) xref database map suitable for writing to EDN.

Transform raw clj-kondo analysis data into the clj-xref data model.
Returns a flat (unindexed) xref database map suitable for writing to EDN.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries