Clojure only.

clj-xref.emit

Read and write xref database EDN files.

Read and write xref database EDN files.
raw docstring

read-ednclj

(read-edn path)

Read an xref database from an EDN file at path.

Read an xref database from an EDN file at `path`.
sourceraw docstring

write-ednclj

(write-edn db path)

Write an xref database to an EDN file at path. Creates parent directories if needed. Writes to a temp file first, then atomically renames to prevent corruption on interrupted writes.

Write an xref database to an EDN file at `path`.
Creates parent directories if needed. Writes to a temp file first,
then atomically renames to prevent corruption on interrupted writes.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries