clj-xref.graph

DOT/Graphviz output for namespace and call graphs.

DOT/Graphviz output for namespace and call graphs.
raw docstring

call-graph-dotclj

(call-graph-dot db sym & [opts])

Generate DOT output for a call graph rooted at sym. Options are passed to clj-xref.core/call-graph.

Generate DOT output for a call graph rooted at `sym`.
Options are passed to `clj-xref.core/call-graph`.
sourceraw docstring

ns-dep-dotclj

(ns-dep-dot db & [{:keys [namespaces]}])

Generate DOT output for the namespace dependency graph. Options: :namespaces - restrict to these namespaces (default: all in db)

Generate DOT output for the namespace dependency graph.
Options:
  :namespaces - restrict to these namespaces (default: all in db)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries