Transform clj-kondo analysis data into the clj-xref data model.
Transform clj-kondo analysis data into the clj-xref data model.
(analyze paths & [{:keys [project kondo-config]}])Run clj-kondo analysis on paths and return a flat xref database map.
Options:
:project - project name string
:kondo-config - extra config map merged into clj-kondo config
Run clj-kondo analysis on `paths` and return a flat xref database map. Options: :project - project name string :kondo-config - extra config map merged into clj-kondo config
(merge-analysis existing-db new-db files)Merge new analysis into an existing database, replacing entries from the re-analyzed files. Used for incremental updates.
Merge new analysis into an existing database, replacing entries from the re-analyzed files. Used for incremental updates.
(transform-analysis analysis {:keys [paths project]})Transform raw clj-kondo analysis data into the clj-xref data model. Returns a flat (unindexed) xref database map suitable for writing to EDN.
Transform raw clj-kondo analysis data into the clj-xref data model. Returns a flat (unindexed) xref database map suitable for writing to EDN.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |