Read and write xref database EDN files.
Read and write xref database EDN files.
(read-edn path)Read an xref database from an EDN file at path.
Read an xref database from an EDN file at `path`.
(write-edn db path)Write an xref database to an EDN file at path.
Creates parent directories if needed. Writes to a temp file first,
then atomically renames to prevent corruption on interrupted writes.
Write an xref database to an EDN file at `path`. Creates parent directories if needed. Writes to a temp file first, then atomically renames to prevent corruption on interrupted writes.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |