DOT/Graphviz output for namespace and call graphs.
DOT/Graphviz output for namespace and call graphs.
(call-graph-dot db sym & [opts])Generate DOT output for a call graph rooted at sym.
Options are passed to clj-xref.core/call-graph.
Generate DOT output for a call graph rooted at `sym`. Options are passed to `clj-xref.core/call-graph`.
(ns-dep-dot db & [{:keys [namespaces]}])Generate DOT output for the namespace dependency graph. Options: :namespaces - restrict to these namespaces (default: all in db)
Generate DOT output for the namespace dependency graph. Options: :namespaces - restrict to these namespaces (default: all in db)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |